import java.awt.Color;

/**
 * A Mine is a type of CellDweller that the player is trying to detect
 * and mark with a flag Marker.
 * 
 * @author Phil Reakes
 */
public class Mine extends CellDweller
{

    // The color representing a mined Cell that has 
    // been foolishly clicked by the player
    final static Color REVEAL_COLOR = Color.red;
    
    /**
     * Constructor for Mines. Places the mine on a specified cell.
     * 
     * @param cell  the cell on which this mine is to be placed.
     */
     public Mine( Cell cell ) 
     {
        // call CellDweller's constructor
        super( cell );
     }

    /**
     * Reveal this mine. 
     */
    public void reveal()
    {
        getCell().setBackground( Mine.REVEAL_COLOR ); 
    }
 
    /**
     * Check whether the player has correctly marked this mine with a flag.
     * 
     * @return     true if the mine is flagged  
     */
     public boolean isFlagged()
     {
        // if the Cell is marked
        if( parentCell.hasMarker() )
        {
            Marker marker = parentCell.getMarker();
            
            // ...and the Marker is a flag
            if( marker.getType() == Marker.FLAG ) 
            {
                return true;
            }
        }
        
        // if there's no marker, or the marker isn't a flag...
        return false;
        
    } // method isFlagged
    
} // class Mine
